# textual-fspicker

## Introduction

This library provides a simple set of filesystem navigation and picking
dialogs The aim is to provide "ready to go" dialogs that should also be
fairly easy to tailor to your own applications.

![Opening a file](https://raw.githubusercontent.com/davep/textual-fspicker/main/.images/file-open.png)
![Saving a file](https://raw.githubusercontent.com/davep/textual-fspicker/main/.images/file-save.png)

## Installing

The package can be installed with `pip` or related tools, for example:

```sh
$ pip install textual-fspicker
```

## Using the library

Please see [the main documentation for the
library](https://textual-fspicker.davep.dev/) for details on how to use it.

## TODO

See [the TODO tag in
issues](https://github.com/davep/textual-fspicker/issues?q=is%3Aissue+is%3Aopen+label%3ATODO)
to see what I'm planning.


[//]: # (README.md ends here)
